@@ -15,7 +15,7 @@ fs_make_public <- function(article_id, session = fs_get_auth()){
   base <- "http://api.figshare.com/v1"
   method <- paste("my_data/articles", article_id, "action/make_public", sep="/")
     request = paste(base, method, sep="/")
-  POST(request, session)
+  POST(request, config(token = session))
 }
 
 
